﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Linq;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Operators;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.DataAnalysis.Symbolic.Tracking {
  [Item("SchemaCleanupOperator", "Operator which removes the schemas from the global scope after they have been evaluated.")]
  [StorableClass]
  public class SchemaCleanupOperator : SingleSuccessorOperator {
    public SchemaCleanupOperator() { }

    protected SchemaCleanupOperator(SchemaCleanupOperator original, Cloner cloner) : base(original, cloner) { }

    public override IDeepCloneable Clone(Cloner cloner) { return new SchemaCleanupOperator(this, cloner); }

    [StorableConstructor]
    protected SchemaCleanupOperator(bool deserializing) : base(deserializing) { }

    public override IOperation Apply() {
      foreach (var s in ExecutionContext.Scope.SubScopes.Where(x => x.Name.Equals("Schema"))) {
        s.Variables.Clear();
      }
      ExecutionContext.Scope.SubScopes.RemoveAll(x => x.Name.Equals("Schema"));
      return base.Apply();
    }
  }
}
